<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <title>Story Game</title>

    <link rel="import" href="/static/bower_components/story-components/story-container.html">

    <!-- Bootstrap -->
    <link href="/static/bower_components/bootstrap/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
      body {
        padding: 0;
        margin: 0;
      }
      story-container {
        margin: auto;
        width: calc(100vmin - 20px);
        height: calc(100vmin - 20px);
        box-shadow: 0 1px 7px black;
      }
    </style>
    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
  </head>
  <body>
    <story-container id="story"></story-container>
    <!-- Polyfill Web Components support for older browsers -->
    <script src="/static/bower_components/webcomponentsjs/webcomponents.min.js"></script>
    <!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.3/jquery.min.js"></script>
    <!-- Include all compiled plugins (below), or include individual files as needed -->
    {# <script src="js/bootstrap.min.js"></script>#}
    <script>
      document.querySelector("#story").loadJson("{{ story.to_json|escapejs }}");
    </script>
  </body>
</html>
